@@ -9,6 +9,8 @@ ARROW_WIDTH = ARROW_HEIGHT/2
 AGGREGATION = 1
 INHERITANCE = 2
 
+DESCRIPTION = "description"
+OPTIONAL = "optional"
 
 VALUE = "Value"
 FORMAT = "Format"
